@@ -1,23 +1,7 @@
-require(ggplot2)
-
-#' GeomAxis
-#' A special ggplot2 geom for drawing the tour axes
-#' 
-#' @keywords internal
-#' @param Geom previous information
-#' @param new function to set up the axis
-#' @author Hadley Wickham \email{h.wickham@@gmail.com}
-#' @aliases geom_axis
-#' @examples
-#' print(ggplot(dd_example("tour2d")))
-GeomAxis <- proto(Geom, {
-  new <- function(., data=NULL, stat=NULL, position=NULL, ...){
-    do.call("layer", list(mapping=NULL, data=data, stat=stat, geom=., position=position, ..., inherit.aes = FALSE))
-  }
-  
-  draw <- function(., data, scales, coordinates, location = c(0.2, 0.2), size=0.9, colour = "black", ...) {
-    axesVp <- axesViewport(data, location)
-    axes <- axesGrob(data, gp=gpar(col = colour))
+GeomAxis <- proto(ggplot2:::Geom, {
+  draw <- function(., data, scales, coordinates, location = c(0.2, 0.2), size=0.9, colour = "black", axis, ...) {
+    axesVp <- axesViewport(axis, location)
+    axes <- axesGrob(axis, gp=gpar(col = colour))
     
     gTree(
       children = gList(axes), 
@@ -26,7 +10,6 @@ GeomAxis <- proto(Geom, {
   }
 
   objname <- "axis"
-  icon <- function(.) {}
   desc <- "Projection axes"
   
   default_stat <- function(.) StatIdentity
@@ -35,11 +18,20 @@ GeomAxis <- proto(Geom, {
   
 })
 
-#' Geom Axis
+#' Geom Axis.
+#'
 #' A special ggplot2 geom for drawing the tour axes
 #' 
 #' @param ... should include data, location, aes\_string information
 #' @author Hadley Wickham \email{h.wickham@@gmail.com}
 #' @keywords internal
-#' @aliases GeomAxis
-geom_axis <- function(...) GeomAxis$new(...)
\ No newline at end of file
+#' @export
+#' @examples
+#' library(ggplot2)
+#' print(ggplot(dd_example("tour2d")))
+geom_axis <- function(axis, location, ...) {
+  GeomAxis$new(
+    geom_params = list(axis = axis, location = location),
+    inherit.aes = FALSE
+  )
+}
\ No newline at end of file
