@@ -45,4 +45,9 @@ zeeThemAll <- function()
 	example(ggplot.scatmat)
 	example(ggplot.parcoords)
 	example(ggplot.timeseries)	
-}
\ No newline at end of file
+}
+
+
+"%||%" <- function(a, b) {
+  if (!is.null(a)) a else b
+}
